@@ -4,14 +4,16 @@ from typing import AsyncGenerator
 import pytest
 
 from pywizlight import wizlight
-from pywizlight.tests.fake_bulb import startup_bulb
 from pywizlight.exceptions import WizLightNotKnownBulb
+from pywizlight.tests.fake_bulb import startup_bulb
 
 
 @pytest.fixture()
 async def no_module_bulb() -> AsyncGenerator[wizlight, None]:
-    shutdown = startup_bulb(module_name="MISSING", firmware_version="1.16.64")
-    bulb = wizlight(ip="127.0.0.1")
+    shutdown, port = await startup_bulb(
+        module_name="MISSING", firmware_version="1.16.64"
+    )
+    bulb = wizlight(ip="127.0.0.1", port=port)
     yield bulb
     await bulb.async_close()
     shutdown()
